# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "wireshark",
        "version": "1.10.12",
        "version_strings": ["Wireshark 1.10.12"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/wireshark/1.10.13/1.fc20/x86_64/",
        "package_name": "wireshark-1.10.13-1.fc20.x86_64.rpm",
        "product": "wireshark",
        "version": "1.10.13",
    },
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "wireshark-1.10.14-25.el7.i686.rpm",
        "product": "wireshark",
        "version": "1.10.14",
    },
]
