# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "icecast",
        "version": "2.3.0",
        "version_strings": ["Icecast 2.3.0"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/icecast/2.3.1/4.fc7/x86_64/",
        "package_name": "icecast-2.3.1-4.fc7.x86_64.rpm",
        "product": "icecast",
        "version": "2.3.1",
    },
    {
        "url": "http://www.rpmfind.net/linux/fedora/linux/development/rawhide/Everything/aarch64/os/Packages/i//",
        "package_name": "icecast-2.4.4-6.fc34.aarch64.rpm",
        "product": "icecast",
        "version": "2.4.4",
    },
]
