# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "openldap",
        "version": "2.4.37",
        "version_strings": ["ldapsearch 2.4.37"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/openldap/2.4.34/1.fc18/x86_64/",
        "package_name": "openldap-clients-2.4.34-1.fc18.x86_64.rpm",
        "product": "openldap",
        "version": "2.4.34",
    },
    {
        "url": "https://mirrors.kernel.org/mageia/distrib/5/x86_64/media/core/release/",
        "package_name": "openldap-clients-2.4.40-3.mga5.x86_64.rpm",
        "product": "openldap",
        "version": "2.4.40",
    },
]
