# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "openssh", "version": "6.9", "version_strings": ["OpenSSH_6.9"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/openssh/6.8p1/1.1.fc23/x86_64/",
        "package_name": "openssh-clients-6.8p1-1.1.fc23.x86_64.rpm",
        "product": "openssh",
        "version": "6.8p1",
    }
]
