# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "irssi", "version": "1.0.0", "version_strings": ["irssi 1.0.0"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/irssi/1.0.1/1.fc26/x86_64/",
        "package_name": "irssi-1.0.1-1.fc26.x86_64.rpm",
        "product": "irssi",
        "version": "1.0.1",
    },
    {
        "url": "https://mirrors.kernel.org/mageia/distrib/5/x86_64/media/core/release/",
        "package_name": "irssi-0.8.16-4.mga5.x86_64.rpm",
        "product": "irssi",
        "version": "0.8.16",
    },
]
