# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "libxml2",
        "version": "2.9.0",
        "version_strings": ["/libxml2-2.9.0/", "xmlNewElementContent : name != NULL !"],
    }
]
package_test_data = [
    {
        "url": "https://archives.fedoraproject.org/pub/archive/fedora/linux/releases/30/Everything/x86_64/os/Packages/l/",
        "package_name": "libxml2-2.9.9-2.fc30.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.9",
    },
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "libxml2-2.9.1-6.el7.5.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.1",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.2-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.2",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.3-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.3",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.4-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.4",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.5-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.5",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.6-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.6",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.7-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.7",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.7.8-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.7.8",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.8.0-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.8.0",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.0-0rc0.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.0",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.0-0rc1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.0",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.0-0rc2.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.0",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.0-1.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.0",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.1-1.fc17.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.1",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.2-0rc1.fc19.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.2",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.2-0rc2.fc19.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.2",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.2-1.fc19.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.2",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.3-1.fc23.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.3",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.4-0rc1.fc23.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.4",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.4-0rc2.fc23.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.4",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.4-1.fc23.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.4",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.5-0rc1.fc24.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.5",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.5-0rc2.fc24.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.5",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.5-1.fc24.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.5",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.6-0rc1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.6",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.6-1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.6",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.7-0rc1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.7",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.7-1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.7",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.8-0rc1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.8",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.8-1.fc26.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.8",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.9-0rc1.fc28.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.9",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.9-0rc2.fc28.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.9",
    },
    {
        "url": "http://xmlsoft.org/sources/",
        "package_name": "libxml2-2.9.9-1.fc28.x86_64.rpm",
        "product": "libxml2",
        "version": "2.9.9",
    },
]
