# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "avahi", "version": "0.6.24", "version_strings": ["avahi 0.6.24"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/avahi/0.6.26/3.fc14/x86_64/",
        "package_name": "avahi-0.6.26-3.fc14.x86_64.rpm",
        "product": "avahi",
        "version": "0.6.26",
    },
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "avahi-0.6.31-20.el7.x86_64.rpm",
        "product": "avahi",
        "version": "0.6.31",
    },
]
