# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "p7zip",
        "version": "16.02",
        "version_strings": ["7-Zip [64] 16.02 : Copyright"],
    }
]
package_test_data = [
    {
        "url": "https://download-ib01.fedoraproject.org/pub/fedora/linux/releases/33/Everything/aarch64/os/Packages/p/",
        "package_name": "p7zip-16.02-18.fc33.aarch64.rpm",
        "product": "p7zip",
        "version": "16.02",
    }
]
