# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "nginx",
        "version": "1.13.2",
        "version_strings": ["NGINX environment variable", "nginx/1.13.2"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/nginx/1.8.0/10.fc22/x86_64/",
        "package_name": "nginx-1.8.0-10.fc22.x86_64.rpm",
        "product": "nginx",
        "version": "1.8.0",
    }
]
