# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "mysql",
        "version": "8.0.20",
        "version_strings": [
            r"mysql-8.0-8.0.20",
            r"To buy MySQL Enterprise support, training, or other products, visit:",
        ],
    }
]
package_test_data = [
    {
        "url": "http://ports.ubuntu.com/pool/main/m/mysql-8.0/",
        "package_name": "mysql-client-core-8.0_8.0.19-0ubuntu5_arm64.deb",
        "product": "mysql",
        "version": "8.0.19",
    }
]
