# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "curl", "version": "7.34.0", "version_strings": ["curl 7.34.0"]}
]
package_test_data = [
    {
        "url": "https://archives.fedoraproject.org/pub/archive/fedora/linux/releases/20/Everything/x86_64/os/Packages/c/",
        "package_name": "curl-7.32.0-3.fc20.x86_64.rpm",
        "product": "curl",
        "version": "7.32.0",
    },
    {
        "url": "http://www.rpmfind.net/linux/fedora/linux/development/rawhide/Everything/aarch64/os/Packages/c/",
        "package_name": "curl-7.74.0-2.fc34.aarch64.rpm",
        "product": "curl",
        "version": "7.74.0",
    },
]
