# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "gcc",
        "version": "9.3.1",
        "version_strings": ["gcc 9.3.1"],
    }
]
package_test_data = [
    {
        "url": "http://mirrors.kernel.org/fedora/releases/33/Everything/x86_64/os/Packages/g/",
        "package_name": "gcc-10.2.1-3.fc33.x86_64.rpm",
        "product": "gcc",
        "version": "10.2.1",
    }
]
