# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "dovecot", "version": "2.2.11", "version_strings": ["Dovecot v2.2.11"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/dovecot/2.2.10/1.fc20/x86_64/",
        "package_name": "dovecot-2.2.10-1.fc20.x86_64.rpm",
        "product": "dovecot",
        "version": "2.2.10",
    },
    {
        "url": "http://rpmfind.net/linux/mageia/distrib/5/x86_64/media/core/updates/",
        "package_name": "dovecot-2.2.13-5.1.mga5.x86_64.rpm",
        "product": "dovecot",
        "version": "2.2.13",
    },
]
