<section id="showcase">
    <div class="container">
        <div class="row ">
            <div class="col-12 bg-light text-right pt-2 ">
                <button class="btn btn-info btn-sm" onclick="modeInteractive()">Interactive Mode</button>
            </div>
        </div>
        <div class="row">
            <div class="col text-center" style="border: 3px solid lightgrey; padding: 0.5em; margin-top:10px">
                <span class="h2">CVE Binary Tool {{ version }}</span>
                <p class="h6">
                    <small>Report Generated: {{ date }}</small>
                </p>
            </div>
        </div>
        <div class="row mt-3">
            <div class="col-12 mt-3">
                <span class="h3 text-primary">Summary</span>
                <hr class="bg-danger">    
            </div>
            <div class="col-12 mt-3">
                <table class="table">
                    {% if directory | length != 0 %}
                        <tr>
                            <th>Directory Scanned</th>
                            <td class="text-dark">{{ directory }}</td>
                        </tr>
                    {% endif %}
                    <tr >
                        <th>Total Scanned Files</th>
                        <!-- If CSV or JSON input total scanned file is products_with_cve + products_without_cve -->
                        <td>{{ total_files if directory | length != 0 else (products_with_cve + products_without_cve) }}</td>
                    </tr>
                    <tr>
                        <th>Vulnerable Files</th>
                        <td>{{ products_with_cve }}</td>
                    </tr>
                        <th>No Known Vulnerability</th>
                        <td>{{ products_without_cve }}</td>
                    </tr>
                </table>
            </div>
            
        </div>
    </div>
</section>