# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "cups", "version": "1.2.4", "version_strings": ["CUPS v1.2.4"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/cups/1.3.3/1.fc8/x86_64/",
        "package_name": "cups-1.3.3-1.fc8.x86_64.rpm",
        "product": "cups",
        "version": "1.3.3",
    }
]
