# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "openvpn", "version": "2.3.13", "version_strings": ["OpenVPN 2.3.13"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/openvpn/2.4.1/1.fc25/x86_64/",
        "package_name": "openvpn-2.4.1-1.fc25.x86_64.rpm",
        "product": "openvpn",
        "version": "2.4.1",
    },
    {
        "url": "http://rpmfind.net/linux/mageia/distrib/5/x86_64/media/core/updates/",
        "package_name": "openvpn-2.3.12-1.mga5.x86_64.rpm",
        "product": "openvpn",
        "version": "2.3.12",
    },
]
