# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "libjpeg-turbo",
        "version": "2.0.1",
        "version_strings": [
            "LIBJPEGTURBO_2.0.1",
            "Invalid JPEG file structure: two SOF markers",
        ],
    }
]
package_test_data = [
    {
        "url": "https://archives.fedoraproject.org/pub/archive/fedora/linux/releases/30/Everything/x86_64/os/Packages/l/",
        "package_name": "libjpeg-turbo-2.0.2-1.fc30.x86_64.rpm",
        "product": "libjpeg-turbo",
        "version": "2.0.2",
    }
]
