# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

__all__ = [
    "accountsservice",
    "avahi",
    "bash",
    "bind",
    "binutils",
    "bolt",
    "bubblewrap",
    "busybox",
    "bzip2",
    "cryptsetup",
    "cups",
    "curl",
    "dnsmasq",
    "dovecot",
    "dpkg",
    "enscript",
    "expat",
    "ffmpeg",
    "freeradius",
    "ftp",
    "gcc",
    "gimp",
    "glibc",
    "gnupg",
    "gnutls",
    "gpgme",
    "gstreamer",
    "haproxy",
    "hostapd",
    "icecast",
    "international_components_for_unicode",
    "irssi",
    "kerberos",
    "kerberos_5",
    "libarchive",
    "libcurl",
    "libdb",
    "libgcrypt",
    "libjpeg-turbo",
    "libsndfile",
    "libsoup",
    "libssh2",
    "libvirt",
    "libxslt",
    "logrotate",
    "mariadb",
    "memcached",
    "mysql",
    "netpbm",
    "nss",
    "tiff",
    "lighttpd",
    "ncurses",
    "nessus",
    "nginx",
    "node",
    "ntp",
    "openafs",
    "openjpeg",
    "openldap",
    "openssh",
    "openssl",
    "openswan",
    "openvpn",
    "p7zip",
    "png",
    "polarssl",
    "postgresql",
    "pspp",
    "python",
    "qt",
    "radare2",
    "rsyslog",
    "samba",
    "sqlite",
    "strongswan",
    "subversion",
    "syslog-ng",
    "systemd",
    "tcpdump",
    "varnish",
    "webkitgtk",
    "wireshark",
    "wpa_supplicant",
    "xerces",
    "xml2",
    "zlib",
]
