# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "libvirt",
        "version": "1.2.3",
        "version_strings": ["LIBVIRT_PRIVATE_1.2.3"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/libvirt/1.2.2/1.fc21/x86_64/",
        "package_name": "libvirt-client-1.2.2-1.fc21.x86_64.rpm",
        "product": "libvirt",
        "version": "1.2.2",
    }
]
