# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "rsyslog", "version": "5.5.6", "version_strings": ["rsyslog 5.5.6"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/rsyslog/5.5.7/1.fc15/x86_64/",
        "package_name": "rsyslog-5.5.7-1.fc15.x86_64.rpm",
        "product": "rsyslog",
        "version": "5.5.7",
    }
]
