# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "tcpdump", "version": "4.9.0", "version_strings": ["tcpdump-4.9.0"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/tcpdump/4.9.1/1.fc27/x86_64/",
        "package_name": "tcpdump-4.9.1-1.fc27.x86_64.rpm",
        "product": "tcpdump",
        "version": "4.9.1",
    },
]
