# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "kerberos",
        "version": "5-1.15.1",
        "version_strings": [
            "An unknown option was passed in to kerberos",
            "CLIENT kerberos 5-1.15.1",
            "KRB5_BRAND: ",
        ],
    },
    {
        "product": "kerberos",
        "version": "5-1.15.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1",
        "version_strings": [
            "An unknown option was passed in to kerberos",
            "CLIENT kerberos 5-1.15.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1",
            "KRB5_BRAND: ",
        ],
    },
]
package_test_data = {}
