<li class="list-group-item">
    <div class="row">
        <div class="col-sm">
            {{cve_number}} <span class="badge badge-pill bg-{{ tag }}">{{ tag }}</span>
        </div>
        <div class="col-sm">
            <span class="badge badge-primary badge-pill bg-{{ severity }}">{{ severity }}</span>
            <div class="float-right">
                <button class="btn" data-toggle="collapse" data-target="#info{{ var_id }}"><svg width="1em" height="1em"
                        viewBox="0 0 16 16" class="bi bi-caret-down-fill" fill="currentColor"
                        xmlns="http://www.w3.org/2000/svg">
                        <path
                            d="M7.247 11.14L2.451 5.658C1.885 5.013 2.345 4 3.204 4h9.592a1 1 0 0 1 .753 1.659l-4.796 5.48a1 1 0 0 1-1.506 0z" />
                    </svg></button>
            </div>
        </div>
    </div>

    <div id="info{{ var_id }}" class="collapse bg-white" data-parent="#accord{{ fix_id }}">
        <p class="summary">{{ description }} <a href="https://nvd.nist.gov/vuln/detail/{{ cve_number}}"
                target="_blank">..read more</a></p>
    </div>
</li>