# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "network_security_services",
        "version": "3.37.1",
        "version_strings": [
            "$Header: NSS 3.37.1 ",
            "Version: NSS 3.37.1 Basic",
            "@#NSS 3.37.1 Basic",
            "# SSL/TLS secrets log file, generated by NSS",
        ],
    }
]
package_test_data = [
    {
        "url": "http://mirror.centos.org/altarch/7/os/aarch64/Packages/",
        "package_name": "nss-3.44.0-7.el7_7.aarch64.rpm",
        "product": "network_security_services",
        "version": "3.44",
    },
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/nss/3.37.3/3.fc29/x86_64/",
        "package_name": "nss-3.37.3-3.fc29.x86_64.rpm",
        "product": "network_security_services",
        "version": "3.37.3",
    },
]
