# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "ncurses",
        "version": "6.1",
        "version_strings": ["_nc_first_name", "ncurses 6.1"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/ncurses/6.2/1.20200222.fc33/x86_64/",
        "package_name": "ncurses-6.2-1.20200222.fc33.x86_64.rpm",
        "product": "ncurses",
        "version": "6.2",
    },
    {
        "url": "https://mirrors.edge.kernel.org/centos/7/os/x86_64/Packages/",
        "package_name": "ncurses-libs-5.9-14.20130511.el7_4.x86_64.rpm",
        "product": "ncurses",
        "version": "5.9",
    },
]
