# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "webkitgtk",
        "version": "1.5.12",
        "version_strings": ["webkitgtk-1.5.12"],
    }
]
package_test_data = [
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "webkitgtk3-2.4.11-2.el7.x86_64.rpm",
        "product": "webkitgtk",
        "version": "2.4.11",
    },
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/webkitgtk/2.0.1/1.fc19/x86_64/",
        "package_name": "webkitgtk-2.0.1-1.fc19.x86_64.rpm",
        "product": "webkitgtk",
        "version": "2.0.1",
    },
]
