# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "wpa_supplicant",
        "version": "2.8",
        "version_strings": ["wpa_supplicant v2.8"],
    }
]
package_test_data = [
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "wpa_supplicant-2.6-12.el7.x86_64.rpm",
        "product": "wpa_supplicant",
        "version": "2.6",
    }
]
