# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "openswan", "version": "2.6.30", "version_strings": ["Openswan 2.6.30"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/openswan/2.6.31/1.fc14/x86_64/",
        "package_name": "openswan-2.6.31-1.fc14.x86_64.rpm",
        "product": "openswan",
        "version": "2.6.31",
    },
]
