# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "libarchive",
        "version": "3.2.0",
        "version_strings": ["libarchive 3.2.0"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/libarchive/3.3.3/1.fc28/x86_64/",
        "package_name": "libarchive-3.3.3-1.fc28.x86_64.rpm",
        "product": "libarchive",
        "version": "3.3.3",
    },
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "libarchive-3.1.2-14.el7_7.x86_64.rpm",
        "product": "libarchive",
        "version": "3.1.2",
    },
]
