# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "varnish", "version": "4.1.1", "version_strings": ["varnish-4.1.1"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/varnish/4.0.5/1.el7/x86_64/",
        "package_name": "varnish-4.0.5-1.el7.x86_64.rpm",
        "product": "varnish",
        "version": "4.0.5",
    }
]
