# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "libsndfile",
        "version": "1.0.25",
        "version_strings": ["libsndfile-1.0.25"],
    }
]
package_test_data = [
    {
        "url": "http://mirror.centos.org/altarch/7/os/aarch64/Packages/",
        "package_name": "libsndfile-1.0.25-12.el7.aarch64.rpm",
        "product": "libsndfile",
        "version": "1.0.25",
    }
]
