# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {"product": "radare2", "version": "3.3.0", "version_strings": ["rafind2 v3.3.0"]}
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/radare2/3.0.1/2.fc27/x86_64/",
        "package_name": "radare2-3.0.1-2.fc27.x86_64.rpm",
        "product": "radare2",
        "version": "3.0.1",
    }
]
