# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "strongswan",
        "version": "4.6.3",
        "version_strings": ["strongSwan 4.6.3"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/strongswan/4.6.2/1.fc16/x86_64/",
        "package_name": "strongswan-4.6.2-1.fc16.x86_64.rpm",
        "product": "strongswan",
        "version": "4.6.2",
    }
]
