# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = {}
package_test_data = [
    {
        "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
        "package_name": "krb5-libs-1.15.1-50.el7.x86_64.rpm",
        "product": "kerberos_5",
        "version": "1.15.1",
    }
]
