# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "nessus",
        "version": "6.8.1",
        "version_strings": ["nessus_lib_version", "Nessus 6.8.1"],
    }
]
package_test_data = [
    {
        "url": "https://archives.fedoraproject.org/pub/archive/fedora/linux/releases/30/Everything/aarch64/os/Packages/n/",
        "package_name": "nessus-libraries-2.2.11-16.fc29.aarch64.rpm",
        "product": "nessus",
        "version": "2.2.11",
    }
]
