/* Main CSS File for CVE Binary Tool HTML Reports */

/* Style common to whole template */
.text-color-main{
    color: #1d3557;
}
.borderButton{
    border: 1px solid #1d3557;
}
h4{
    font-size: 1.75vw;
} 
h5{
    font-size: 1.25vw;
}
h6{
    font-size: 1vw;
}
label{
    font-size: 1vw;
}
.btn{
    font-size: 1vw;
}
p{
    font-size: 0.9vw;
}
a{
    font-size: 0.9vw;
    cursor: pointer;
}

/* Style for Base */
.bg-nav{
    background-color: #363e42;
}
.bg-title{
    background-color: #42494c;
}
.btn-filter{
    background-color: #4fc4ff;
}

/* Style for Dashboard */
.bg-header-dash{
    background-color: #e5e5e5;
}

/* Style for Row Product */
.analysis{
    margin: 10px 0px 0px 0px;
}
/* .pHeading{
    margin: 10px 0px;
    border-width: 0;
    background-color: #4fc4ff;
} */

/* Style for Row CVE */
.bg-CRITICAL{
    background-color: #f25f5c;
}
.bg-HIGH{
    background-color: #ee6c4d;
}
.bg-MEDIUM{
    background-color: #f4d35e;
}
.bg-LOW{
    background-color: #90a955;
}
.listCVE{
    margin: 10px 0px 10px 0px;
}
.summary{
    margin: 5px;
}

/* Style for Footer */
.bg-footer{
    background-color: #caced2;
}

/* util css */

/* margin */
.m-t-5{
    margin-top: 5px;
}
.m-b-5{
    margin-bottom: 5px;
}
.m-l-5{
    margin-left: 5px;
}
.m-r-5{
    margin-right: 5px;
}
.m-t-10{
    margin-top: 10px;
}
.m-b-10{
    margin-bottom: 10px;
}
.m-l-10{
    margin-left: 10px;
}
.m-r-10{
    margin-right: 10px;
}
.m-t-15{
    margin-top: 15px;
}
.m-b-15{
    margin-bottom: 15px;
}
.m-l-15{
    margin-left: 15px;
}
.m-r-15{
    margin-right: 15px;
}
.m-t-20{
    margin-top: 20px;
}
.m-b-20{
    margin-bottom: 20px;
}
.m-l-20{
    margin-left: 20px;
}
.m-r-15{
    margin-right: 20px;
}

/* padding */

.p-t-5{
    padding-top: 5px;
}
.p-b-5{
    padding-bottom: 5px;
}
.p-t-10{
    padding-top: 10px;
}
.p-b-10{
    padding-bottom: 10px;
}


/* media queries*/
@media only screen and (max-width: 575.98px) {
    h4{
        font-size: 3.5vw;
    }
    h5{
        font-size: 3.5vw;
    }
    h6{
        font-size: 3.5vw;
    }
    .btn{
        font-size: 3.5vw;
    }
    p{
        font-size: 2.5vw;
    }
    a{
        font-size: 2.5vw;
    }
    label{
        font-size: 3.5vw;
    }
}

@media only screen and (max-width: 767.98px) {
    h4{
        font-size: 2.4vw;
    }
    h5{
        font-size: 2.3vw;
    }
    h6{
        font-size: 2.1vw;
    }
    .btn{
        font-size: 2.1vw;
    }
    p{
        font-size: 1.9vw;
    }
    a{
        font-size: 1.9vw;
    }
    label{
        font-size: 2.1vw;
    }
}

@media only screen and (max-width: 991.98px){
    button{
        margin-top: -25px;
    }
    .btn-filter{
        margin-top: 0px;
    }
}