# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "haproxy",
        "version": "1.7.3",
        "version_strings": ["HA-Proxy version 1.7.3"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/haproxy/1.8.4/2.fc28/x86_64/",
        "package_name": "haproxy-1.8.4-2.fc28.x86_64.rpm",
        "product": "haproxy",
        "version": "1.8.4",
    },
    {
        "url": "https://mirrors.edge.kernel.org/centos/7/os/x86_64/Packages/",
        "package_name": "haproxy-1.5.18-9.el7.x86_64.rpm",
        "product": "haproxy",
        "version": "1.5.18",
    },
]
