# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "polarssl",
        "version": "1.3.6",
        "version_strings": ["libpolarssl.so.1.3.6.debug"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/polarssl/1.3.7/2.fc21/x86_64/",
        "package_name": "polarssl-1.3.7-2.fc21.x86_64.rpm",
        "product": "polarssl",
        "version": "1.3.7",
    }
]
