# Copyright (C) 2021 Intel Corporation
# SPDX-License-Identifier: GPL-3.0-or-later

mapping_test_data = [
    {
        "product": "postgresql",
        "version": "9.4.3",
        "version_strings": ["PostgreSQL 9.4.3"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org/packages/postgresql/9.4.4/1.fc22/x86_64/",
        "package_name": "postgresql-9.4.4-1.fc22.x86_64.rpm",
        "product": "postgresql",
        "version": "9.4.4",
    }
]
